@@ -1,12 +1,14 @@
 import os
 
 from maitai._azure import MaitaiAsyncAzureOpenAIClient as AsyncAzureOpenAI, MaitaiAzureOpenAIClient as AzureOpenAI
+from maitai._context import ContextManager
 from maitai._evaluator import Evaluator as Evaluator
 from maitai._inference import Inference as Inference
 from maitai._openai import Chat, MaitaiOpenAIClient as OpenAI
 from maitai._openai_async import MaitaiAsyncOpenAIClient as AsyncOpenAI
 
 chat = Chat()
+context = ContextManager()
 
 
 def initialize(api_key):
