@@ -29,7 +29,7 @@ class Evaluator(MaitaiClient):
         super().__init__()
 
     @classmethod
-    async def evaluate_async(cls, session_id, reference_id, action_type, content, content_type=None, application_id=None, application_ref_name=None, callback=None, completion_params: ChatCompletionParams = None,
+    async def evaluate_async(cls, session_id, reference_id, intent, content, content_type=None, application_id=None, application_ref_name=None, callback=None, completion_params: ChatCompletionParams = None,
                              chat_completion_response: ChatCompletionResponse = None, chat_completion_chunk: ChatCompletionChunk = None):
         if content_type is None:
             content_type = _get_content_type(content)
@@ -37,9 +37,9 @@ class Evaluator(MaitaiClient):
             raise Exception('Unable to automatically determine content_type')
         if application_id is None and application_ref_name is None:
             raise Exception('application_id or application_ref_name must be provided')
-        eval_request: EvaluateRequest = cls.create_eval_request(application_id, application_ref_name, session_id, reference_id, action_type, content_type, content)
+        eval_request: EvaluateRequest = cls.create_eval_request(application_id, application_ref_name, session_id, reference_id, intent, content_type, content)
         if completion_params is not None:
-            eval_request.chat_completion_request = cls.create_inference_request(application_ref_name, session_id, reference_id, action_type, False, True, completion_params, callback)
+            eval_request.chat_completion_request = cls.create_inference_request(application_ref_name, session_id, reference_id, intent, False, True, completion_params, callback, False, '')
             if chat_completion_chunk is not None:
                 chat_completion_response = chat_completion_chunk_to_response(chat_completion_chunk, content)
             eval_request.chat_completion_response = chat_completion_response
@@ -47,7 +47,7 @@ class Evaluator(MaitaiClient):
         await asyncio.create_task(cls.send_evaluation_request_async(eval_request, callback))
 
     @classmethod
-    def evaluate(cls, session_id, reference_id, action_type, content, content_type=None, application_id=None, application_ref_name=None, callback=None, partial=None, completion_params: ChatCompletionParams = None,
+    def evaluate(cls, session_id, reference_id, intent, content, content_type=None, application_id=None, application_ref_name=None, callback=None, partial=None, completion_params: ChatCompletionParams = None,
                  chat_completion_response: ChatCompletionResponse = None, chat_completion_chunk: ChatCompletionChunk = None):
         if content_type is None:
             content_type = _get_content_type(content, partial)
@@ -55,9 +55,9 @@ class Evaluator(MaitaiClient):
             raise Exception('Unable to automatically determine content_type')
         if application_id is None and application_ref_name is None:
             raise Exception('application_id or application_ref_name must be provided')
-        eval_request: EvaluateRequest = cls.create_eval_request(application_id, application_ref_name, session_id, reference_id, action_type, content_type, content, partial=partial)
+        eval_request: EvaluateRequest = cls.create_eval_request(application_id, application_ref_name, session_id, reference_id, intent, content_type, content, partial=partial)
         if completion_params is not None:
-            eval_request.chat_completion_request = cls.create_inference_request(application_ref_name, session_id, reference_id, action_type, False, True, completion_params, callback)
+            eval_request.chat_completion_request = cls.create_inference_request(application_ref_name, session_id, reference_id, intent, False, True, completion_params, callback, False, '')
             if chat_completion_chunk is not None:
                 chat_completion_response = chat_completion_chunk_to_response(chat_completion_chunk, content)
             eval_request.chat_completion_response = chat_completion_response
@@ -65,14 +65,14 @@ class Evaluator(MaitaiClient):
         cls.run_async(cls.send_evaluation_request_async(eval_request, callback))
 
     @classmethod
-    def stream_correction(cls, session_id, reference_id, action_type, content_type, content, application_ref_name, partial, fault_description, sentinel_id):
-        eval_request: EvaluateRequest = cls.create_eval_request(None, application_ref_name, session_id, reference_id, action_type, content_type, content, partial=partial,
+    def stream_correction(cls, session_id, reference_id, intent, content_type, content, application_ref_name, partial, fault_description, sentinel_id):
+        eval_request: EvaluateRequest = cls.create_eval_request(None, application_ref_name, session_id, reference_id, intent, content_type, content, partial=partial,
                                                                 fault_description=fault_description)
         eval_request.sentinel_id = sentinel_id
         return cls.send_stream_correction_request(eval_request)
 
     @classmethod
-    def create_eval_request(cls, application_id, application_ref_name, session_id, reference_id, action_type,
+    def create_eval_request(cls, application_id, application_ref_name, session_id, reference_id, intent,
                             content_type, content, partial=None, fault_description=None, chat_completion_response=None):
         eval_request: EvaluateRequest = EvaluateRequest()
         eval_request.evaluation_content_type = content_type
@@ -89,7 +89,7 @@ class Evaluator(MaitaiClient):
         eval_request.application_ref_name = application_ref_name
         eval_request.session_id = session_id
         eval_request.reference_id = reference_id
-        eval_request.action_type = action_type
+        eval_request.action_type = intent
         if fault_description:
             eval_request.fault_description = fault_description
         return eval_request
