@@ -1,14 +1,16 @@
+import warnings
 from typing import Dict, Iterable, List, Mapping, Optional, Union
 
 import httpx
 import openai
 import openai.types as openai_types
 import openai.types.chat as openai_chat_types
+from openai.types.chat import ChatCompletionStreamOptionsParam
 
 import maitai
 from maitai._config import config
 from maitai._evaluator import Evaluator
-from maitai._inference import InferenceException
+from maitai._inference import InferenceException, InferenceWarning
 from maitai._openai_types import Body, Headers, Query
 from maitai._utils import convert_open_ai_chat_completion_chunk, convert_openai_chat_completion, get_chat_completion_params, required_args
 from maitai_common.utils.proto_utils import openai_messages_to_proto
@@ -71,20 +73,26 @@ class Completions:
         self.client = client
 
     @required_args(["session_id", "action_type", "application_ref_name", "messages"],
+                   ["session_id", "intent", "application_ref_name", "messages"],
                    ["session_id", "action_type", "application_ref_name", "messages", "model"],
-                   ["session_id", "action_type", "application_ref_name", "messages", "model", "stream"])
+                   ["session_id", "intent", "application_ref_name", "messages", "model"],
+                   ["session_id", "action_type", "application_ref_name", "messages", "model", "stream"],
+                   ["session_id", "intent", "application_ref_name", "messages", "model", "stream"])
     def create(
         self,
         *,
         # Maitai Arguments
         session_id: Union[str, int] = None,
         reference_id: Union[str, int, None] = None,
-        action_type: str = None,
+        intent: str = None,
+        action_type: str = None,  # DEPRECATED
         application_ref_name: str = None,
         callback: Optional[EvaluateCallback] = None,
         server_side_inference: bool = None,
         evaluation_enabled: bool = None,
         apply_corrections: bool = None,
+        context_retrieval_enabled: bool = None,
+        context_query: str = '',
         # OpenAI Arguments
         messages: Iterable[openai_chat_types.ChatCompletionMessageParam],
         model: Union[str, openai_types.ChatModel, openai.NotGiven] = openai.NOT_GIVEN,
@@ -118,7 +126,9 @@ class Completions:
             raise ValueError("server_side_inference must be true to apply_corrections")
         if apply_corrections is True and evaluation_enabled is False:
             raise ValueError("evaluations must be enabled to apply_corrections")
-        maitai_config = config.get_application_action_config(application_ref_name, action_type)
+        if not intent and action_type:
+            intent = action_type
+        maitai_config = config.get_application_action_config(application_ref_name, intent)
         if server_side_inference is None:
             server_side_inference = maitai_config.inference_location == InferenceLocations.SERVER
         if evaluation_enabled is None:
@@ -145,6 +155,12 @@ class Completions:
             frequency_penalty = maitai_config.frequency_penalty
         if presence_penalty == openai.NOT_GIVEN:
             presence_penalty = maitai_config.presence_penalty
+        if timeout == openai.NOT_GIVEN and maitai_config.timeout > 0:
+            timeout = maitai_config.timeout
+        if stream_options == openai.NOT_GIVEN and stream:
+            stream_options = ChatCompletionStreamOptionsParam(include_usage=True)
+        if context_retrieval_enabled is None:
+            context_retrieval_enabled = maitai_config.context_retrieval_enabled
         completion_params = get_chat_completion_params(
             messages=messages,
             model=model,
@@ -170,12 +186,15 @@ class Completions:
             response_timeout = None
             if isinstance(timeout, float) or isinstance(timeout, int):
                 response_timeout = timeout
-            response = maitai.Inference.infer(session_id, reference_id, action_type, application_ref_name, completion_params, apply_corrections, evaluation_enabled, callback, timeout=response_timeout)
+            response = maitai.Inference.infer(session_id, reference_id, intent, application_ref_name, completion_params, apply_corrections, evaluation_enabled, callback, timeout=response_timeout,
+                                              context_retrieval_enabled=context_retrieval_enabled, context_query=context_query)
             if stream:
                 return _process_inference_stream(response)
             # ChatCompletion only
             chat_completion: Optional[ChatCompletionResponse] = None
             for resp in response:
+                if resp.warning:
+                    warnings.warn(resp.warning, InferenceWarning)
                 if resp.error:
                     raise InferenceException(resp.error)
                 return resp.chat_completion_response
@@ -212,7 +231,7 @@ class Completions:
 
             )
             if stream:
-                return _process_openai_stream(session_id, reference_id, action_type, application_ref_name, messages, response, evaluation_enabled, completion_params, callback)
+                return _process_openai_stream(session_id, reference_id, intent, application_ref_name, messages, response, evaluation_enabled, completion_params, callback)
             else:
                 maitai_completion = convert_openai_chat_completion(response)
                 proto_messages = openai_messages_to_proto(messages)
@@ -222,7 +241,7 @@ class Completions:
                     maitai.Evaluator.evaluate(
                         session_id=session_id,
                         reference_id=reference_id,
-                        action_type=action_type,
+                        intent=intent,
                         content_type=EvaluationContentType.MESSAGE,
                         content=proto_messages,
                         application_ref_name=application_ref_name,
@@ -234,7 +253,7 @@ class Completions:
                     maitai.Inference.store_chat_response(
                         session_id=session_id,
                         reference_id=reference_id,
-                        action_type=action_type,
+                        intent=intent,
                         application_ref_name=application_ref_name,
                         chat_completion_response=maitai_completion,
                         completion_params=completion_params,
@@ -246,7 +265,7 @@ class Completions:
 
 def _process_openai_stream(session_id: Union[str, int],
                            reference_id: Union[str, int, None],
-                           action_type: str,
+                           intent: str,
                            application_ref_name: str,
                            messages: Iterable[openai_chat_types.ChatCompletionMessageParam],
                            stream: openai.Stream[openai_chat_types.ChatCompletionChunk],
@@ -255,42 +274,47 @@ def _process_openai_stream(session_id: Union[str, int],
                            callback: Optional[EvaluateCallback] = None, ) -> Iterable[ChatCompletionChunk]:
     full_body = ""
     proto_messages = openai_messages_to_proto(messages)
+    last_chunk = None
     for chunk in stream:
         maitai_chunk = convert_open_ai_chat_completion_chunk(chunk)
-        content = maitai_chunk.choices[0].delta.content
-        if content is not None:
-            full_body += content
+        if maitai_chunk.choices:
+            last_chunk = maitai_chunk
+            content = maitai_chunk.choices[0].delta.content
+            if content is not None:
+                full_body += content
+        if maitai_chunk.usage and last_chunk is not None and not last_chunk.usage:
+            last_chunk.usage = maitai_chunk.usage
         yield maitai_chunk
-        if maitai_chunk.choices[0].finish_reason:
-            if evaluation_enabled:
-                proto_messages.append(ChatMessage(role="assistant", content=full_body))
-                Evaluator.evaluate(
-                    session_id=session_id,
-                    reference_id=reference_id,
-                    action_type=action_type,
-                    content_type=EvaluationContentType.MESSAGE,
-                    content=proto_messages,
-                    application_ref_name=application_ref_name,
-                    callback=callback,
-                    chat_completion_chunk=maitai_chunk,
-                    completion_params=chat_completion_params,
-                )
-            else:
-                maitai.Inference.store_chat_response(
-                    session_id=session_id,
-                    reference_id=reference_id,
-                    action_type=action_type,
-                    application_ref_name=application_ref_name,
-                    completion_params=chat_completion_params,
-                    final_chunk=maitai_chunk,
-                    content=full_body,
-                    chat_completion_response=None,
-                )
-            return
+    if evaluation_enabled:
+        proto_messages.append(ChatMessage(role="assistant", content=full_body))
+        Evaluator.evaluate(
+            session_id=session_id,
+            reference_id=reference_id,
+            intent=intent,
+            content_type=EvaluationContentType.MESSAGE,
+            content=proto_messages,
+            application_ref_name=application_ref_name,
+            callback=callback,
+            chat_completion_chunk=last_chunk,
+            completion_params=chat_completion_params,
+        )
+    else:
+        maitai.Inference.store_chat_response(
+            session_id=session_id,
+            reference_id=reference_id,
+            intent=intent,
+            application_ref_name=application_ref_name,
+            completion_params=chat_completion_params,
+            final_chunk=last_chunk,
+            content=full_body,
+            chat_completion_response=None,
+        )
 
 
 def _process_inference_stream(stream: Iterable[InferenceStreamResponse]) -> Iterable[ChatCompletionChunk]:
     for infer_resp in stream:
+        if infer_resp.warning:
+            warnings.warn(infer_resp.warning, InferenceWarning)
         if infer_resp.error:
             raise InferenceException(infer_resp.error)
         chunk = infer_resp.chat_completion_chunk
