@@ -16,20 +16,12 @@ MODELS = {
     "gpt-4-0125-preview": "openai",
     "gpt-4-turbo-preview": "openai",
     "gpt-4-1106-preview": "openai",
-    "gpt-4-vision-preview": "openai",
     "gpt-4": "openai",
-    "gpt-4-0314": "openai",
     "gpt-4-0613": "openai",
-    "gpt-4-32k": "openai",
-    "gpt-4-32k-0314": "openai",
-    "gpt-4-32k-0613": "openai",
     "gpt-3.5-turbo": "openai",
     "gpt-3.5-turbo-16k": "openai",
-    "gpt-3.5-turbo-0301": "openai",
-    "gpt-3.5-turbo-0613": "openai",
     "gpt-3.5-turbo-1106": "openai",
     "gpt-3.5-turbo-0125": "openai",
-    "gpt-3.5-turbo-16k-0613": "openai",
 }
 
 DEFAULT_CLIENT_MODEL = "gpt-4o"
@@ -51,6 +43,8 @@ def get_default_config() -> Config:
         n=1,
         frequency_penalty=0,
         presence_penalty=0,
+        timeout=-1,
+        context_retrieval_enabled=False,
     )
 
 
@@ -63,7 +57,7 @@ def reconcile_config_with_default(config_dict: dict) -> Config:
 
 
 def get_model_provider(model_name: str):
-    return MODELS[model_name]
+    return MODELS.get(model_name)
 
 
 def get_models(providers):
